# History of changes

## Version 0.1.2 (2016/11/22)

### Bugs fixed

**Pull requests**

* [PR 12](https://github.com/spyder-ide/loghub/pull/12) - Don't test macOS in Travis
* [PR 9](https://github.com/spyder-ide/loghub/pull/9) - Don't show "Issues" or "Pull requests" sections if there are no issues or PRs to show
* [PR 7](https://github.com/spyder-ide/loghub/pull/7) - Fix contents of temporary file
* [PR 6](https://github.com/spyder-ide/loghub/pull/6) - Remove extra empty lines
* [PR 5](https://github.com/spyder-ide/loghub/pull/5) - Fix PR_SHORT formatting.

In this release 5 pull requests were merged


----


## Version 0.1.0

* Initial release
